#!/bin/sh

. /lib/senao-shell-libs/wifi/wifi-control-libs.sh

### Global variable ###
__json_format=0
__act_name=""
__opt_number=0
__no_color=0
__input_file=""
####

#===  FUNCTION  ================================================================
#         NAME:  usage
#  DESCRIPTION:  Display usage information.
#===============================================================================
usage()
{
    echo "Usage :  $0 [options] [--]

    Options:
    -h  Display this message
    -f  Load file
    -a  Action to Control
            beacon [on/off/show] [Interface/SSID num(1-8)/all (all of athx)]
            hostapd [reload] [Interface/SSID num(1-8)/all (all of athx)]
                    [reconfig] send SIGHUP to hostapd
                    [acl] [deny/accept] [show/clear] [Interface/SSID num(1-8)/all (all of athx)]
                                        [add/del] [00:aa:bb:cc:dd:10] [Interface/SSID num(1-8)/all (all of athx)]
                    [list_sta] [Interface/SSID num(1-8)/all (all of athx)]
                    [check_sta] [Interface/SSID num(1-8)/all (all of athx)] [00:aa:bb:cc:dd:10]
            client [show] [Interface/SSID num(1-8)/all (all of athx)]
                   [kick] [00:aa:bb:cc:dd:10] (reason)
            ssid   [show] [essid/freq]
    -j  Show with Json format (TODO)
    -n  Without color
    -v  Display script version"

}    # ----------  end of function usage  ----------

act_ssid_handle()
{
    local action=$ssid_opt_1
    local opt=""
    for i in `seq 2 ${__opt_number}`
    do
        eval "VAL=$(echo \${ssid_opt_$i})"
        opt="$opt${opt:+ }$VAL"
    done

    case $action in
        "show")
            control_ssid_show $opt
            ;;
        *)
            usage
            exit 1
            ;;
    esac
}


act_client_handle()
{
    local action=$client_opt_1
    local opt=""
    for i in `seq 1 ${__opt_number}`
    do
        eval "VAL=$(echo \${client_opt_$i})"
        opt="$opt${opt:+ }$VAL"
    done

    case $action in
        "kick")
            control_client_kick $opt
            ;;
        "list"|"show")
            control_client_list $opt
            ;;
        *)
            usage
            exit 1
            ;;
    esac
}

act_hostapd_handle()
{
    local action=$hostapd_opt_1
    local opt=""
    for i in `seq 2 ${__opt_number}`
    do
        eval "VAL=$(echo \${hostapd_opt_$i})"
        opt="$opt${opt:+ }$VAL"
    done

    case $action in
        "reload")
            control_hostapd_reload $opt
            ;;
        "reconfig")
            killall -SIGHUP hostapd
            ;;
        "acl")
            control_hostapd_acl $opt
            ;;
        "list_sta")
            control_hostapd_sta $action $opt
            ;;
        "check_sta")
            control_hostapd_sta $action $opt
            ;;
        *)
            usage
            exit 1
            ;;
    esac
}

act_beacon_handle()
{
    local action=$beacon_opt_1
    local opt=""
    for i in `seq 1 ${__opt_number}`
    do
        eval "VAL=$(echo \${beacon_opt_$i})"
        opt="$opt${opt:+ }$VAL"
    done

    case $action in
        "on")
            control_beacon_handle $opt
            ;;
        "off")
            control_beacon_handle $opt
            ;;
        "show")
            control_beacon_handle $opt
            ;;
        "fix")
            control_beacon_handle $opt
            ;;
        *)
            usage
            exit 1
            ;;
    esac
}

action_handle()
{
    __opt_number=0
    while [ "$1" != "" ]
    do
        __opt_number=$(($__opt_number+1))
        eval ${__act_name}_opt_${__opt_number}=$1
        shift
    done
    eval act_${__act_name}_handle
    if [ $? -ne 0 ]
    then
        usage
        exit 1
    else
        exit 0
    fi
}

#-----------------------------------------------------------------------
#  Handle command line arguments
#-----------------------------------------------------------------------

while getopts ":hva:jnf:V:" opt
do
  case $opt in

    h)  usage; exit 0   ;;
    V)
        version=`opkg list zzSENAO_COMMON | awk '{print $3}'`
        input_version=$OPTARG
        major_ver=${version%%.*}
        minor_ver=${version#$major_ver.}
        minor_ver=${minor_ver%%-*}
        input_major_ver=${input_version%.*}
        input_minor_ver=${input_version#*.}
        if [ ${major_ver:-0} -ge ${input_major_ver:-0} ]
        then
            if [ ${minor_ver:-0} -ge ${input_minor_ver:-0} ]
            then
                echo 1
                exit 0
            else
                echo 0
                exit 1
            fi
        else
            echo 0
            exit 1
        fi
        ;;
    v)  opkg list zzSENAO_COMMON | awk '{print $3}'; exit 0   ;;
    j)  __json_format=1;;
    n)  __no_color=1;;
    f)
        __input_file="$OPTARG"
        [ -f "$__input_file" ] || { echo file error!!; exit 1; }
        ;;
    a)
        case "$OPTARG" in
            *)
                __act_name=$OPTARG
                shift $(($OPTIND-1))
                action_handle "$@"
                ;;
        esac
        ;;

    * )  echo -e "\n  Option does not exist : $OPTARG\n"
          usage; exit 1   ;;

  esac    # --- end of case ---
done
shift $(($OPTIND-1))

__act_name=$1
shift
action_handle "$@"

exit 0
